IsolateFeatureData class
Data model for passing feature extraction data to isolates This allows us to pre-load assets in the main thread and pass them to isolates
Constructors
-
IsolateFeatureData({required SongModel song, required Uint8List yamnetModelBytes, required List<
String> yamnetLabels, required String modelVersion, Float32List? audioData}) -
const
Properties
- audioData → Float32List?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelVersion → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- song → SongModel
-
final
-
yamnetLabels
→ List<
String> -
final
- yamnetModelBytes → Uint8List
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited